# A RubyGem for creating mailing, shipping, address, barcode and other labels and rendering as PDF's.
#
# Author::    Aaron Wright  (mailto:acwrightdesign@gmail.com)
# Copyright:: Copyright (c) 2012 Infinite Token LLC
# License::  MIT License

require 'fileutils'

require 'labels/paper'
require 'labels/template'
require 'labels/database'
require 'labels/xml/builder'
require 'labels/pdf/builder'

module Labels
  
  # This class represents a Labels document.
  class Document
    
    # The document Labels::Paper instance
    attr_accessor :paper
    
    # The document Labels::Template instance
    attr_accessor :template
    
    # An array of document Labels::Layer instances
    attr_accessor :layers
    
    # The document Labels::Database instance
    attr_accessor :database
    
    # Creates a new Labels::Document instance with optional content
    def initialize(paper=nil, template=nil, layers=[], database=nil)
      unless paper.nil?
        @paper = paper
      else
        @paper = Labels::Paper.new(Labels::Paper::LETTER)
      end
      
      unless template.nil?
        @template = template
      else
        @template = Labels::Template.new(Labels::Template::DEFAULT)
      end
      
      @layers = layers
      
      unless database.nil?
        @database = database
      else
        @database = Labels::Database.new
      end
    end
    
    # Writes document to filename as XML
    def write(filename)
      FileUtils.mkdir_p(File.dirname(filename))
      File.open(filename, 'w') do |file|
        file.write Labels::XML::Builder.new(self).xml
      end
    end
    alias_method :to_file, :write
    
    # Render document to filename or string
    def render(filename=nil)
      Labels::PDF::Builder.new(self).render(filename)
    end
    alias_method :to_pdf, :render
  end
end