# A RubyGem for creating mailing, shipping, address, barcode and other labels and rendering as PDF's.
#
# Author::    Aaron Wright  (mailto:acwrightdesign@gmail.com)
# Copyright:: Copyright (c) 2012 Infinite Token LLC
# License::  MIT License

require 'optparse'

require 'labels'
require 'labels/version'

module Labels
  
  # This class is the main handler for the command line tool interface.
  # It takes command line arguments and options and renders a barcode 
  # using those options.
  class Exec
    
    # Array of command line arguments
    attr_reader :argv
    
    # The parser instance
    attr_reader :parser
    
    # Hash of parsed options
    attr_reader :options
    
    # The input source
    attr_reader :source
    
    # The output target
    attr_reader :target
    
    # Creates a new instance with given command line arguments and options
    def initialize(argv)
      @argv = argv
      @options = {}
      self._init_parser
      self._parse!
    end
    
    # Runs the command and renders label
    def run
      begin
        document = Labels.open(self.source)
      
        unless document.nil?
          unless self.target.nil?
            document.render(self.target)
          else
            puts document.render
          end
        end
      rescue Exception => e
        puts e.message
      end
    end
    
    protected
    
    # Initializes the option parser instance
    def _init_parser
      @parser ||= OptionParser.new do |opts|
        opts.banner = "Usage: labels [OPTIONS] source target"
        opts.separator ""
        opts.on('-v', '--version')                              { puts self._version ; exit }
        opts.on('-h', '--help')                                 { puts opts ; exit }
        opts.separator ""
      end
      
    end
    
    # Parses the command line arguments
    def _parse!
      
      begin
        self.parser.parse!(@argv)
      rescue
        puts self.parser.help
        exit 1
      end
      
      @source = self.argv.shift
      @target = self.argv.shift
    end

    # Returns the current version
    def _version
      "labels #{Labels::VERSION}"
    end
  end
end